# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\nikvschemas\"\x9b\x01\n\x11IKVDocumentOnWire\x12=\n\x08\x64ocument\x18\x01 \x03(\x0b\x32+.ikvschemas.IKVDocumentOnWire.DocumentEntry\x1aG\n\rDocumentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.ikvschemas.FieldValue:\x02\x38\x01\"E\n\nFieldValue\x12(\n\tfieldType\x18\x01 \x01(\x0e\x32\x15.ikvschemas.FieldType\x12\r\n\x05value\x18\x02 \x01(\x0c\"\xf0\x04\n\x0eIKVStoreConfig\x12\x44\n\rstringConfigs\x18\x01 \x03(\x0b\x32-.ikvschemas.IKVStoreConfig.StringConfigsEntry\x12>\n\nintConfigs\x18\x02 \x03(\x0b\x32*.ikvschemas.IKVStoreConfig.IntConfigsEntry\x12\x42\n\x0c\x66loatConfigs\x18\x03 \x03(\x0b\x32,.ikvschemas.IKVStoreConfig.FloatConfigsEntry\x12\x42\n\x0c\x62ytesConfigs\x18\x04 \x03(\x0b\x32,.ikvschemas.IKVStoreConfig.BytesConfigsEntry\x12\x46\n\x0e\x62ooleanConfigs\x18\x05 \x03(\x0b\x32..ikvschemas.IKVStoreConfig.BooleanConfigsEntry\x1a\x34\n\x12StringConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fIntConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x33\n\x11\x46loatConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x33\n\x11\x42ytesConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x35\n\x13\x42ooleanConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01*l\n\tFieldType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05INT32\x10\x01\x12\t\n\x05INT64\x10\x02\x12\x0b\n\x07\x46LOAT32\x10\x03\x12\x0b\n\x07\x46LOAT64\x10\x04\x12\n\n\x06STRING\x10\x05\x12\t\n\x05\x42YTES\x10\x06\x12\x0b\n\x07\x42OOLEAN\x10\x07\x42 \n\x14\x63om.inlineio.schemasZ\x08schemas/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.inlineio.schemasZ\010schemas/'
  _globals['_IKVDOCUMENTONWIRE_DOCUMENTENTRY']._options = None
  _globals['_IKVDOCUMENTONWIRE_DOCUMENTENTRY']._serialized_options = b'8\001'
  _globals['_IKVSTORECONFIG_STRINGCONFIGSENTRY']._options = None
  _globals['_IKVSTORECONFIG_STRINGCONFIGSENTRY']._serialized_options = b'8\001'
  _globals['_IKVSTORECONFIG_INTCONFIGSENTRY']._options = None
  _globals['_IKVSTORECONFIG_INTCONFIGSENTRY']._serialized_options = b'8\001'
  _globals['_IKVSTORECONFIG_FLOATCONFIGSENTRY']._options = None
  _globals['_IKVSTORECONFIG_FLOATCONFIGSENTRY']._serialized_options = b'8\001'
  _globals['_IKVSTORECONFIG_BYTESCONFIGSENTRY']._options = None
  _globals['_IKVSTORECONFIG_BYTESCONFIGSENTRY']._serialized_options = b'8\001'
  _globals['_IKVSTORECONFIG_BOOLEANCONFIGSENTRY']._options = None
  _globals['_IKVSTORECONFIG_BOOLEANCONFIGSENTRY']._serialized_options = b'8\001'
  _globals['_FIELDTYPE']._serialized_start=884
  _globals['_FIELDTYPE']._serialized_end=992
  _globals['_IKVDOCUMENTONWIRE']._serialized_start=29
  _globals['_IKVDOCUMENTONWIRE']._serialized_end=184
  _globals['_IKVDOCUMENTONWIRE_DOCUMENTENTRY']._serialized_start=113
  _globals['_IKVDOCUMENTONWIRE_DOCUMENTENTRY']._serialized_end=184
  _globals['_FIELDVALUE']._serialized_start=186
  _globals['_FIELDVALUE']._serialized_end=255
  _globals['_IKVSTORECONFIG']._serialized_start=258
  _globals['_IKVSTORECONFIG']._serialized_end=882
  _globals['_IKVSTORECONFIG_STRINGCONFIGSENTRY']._serialized_start=618
  _globals['_IKVSTORECONFIG_STRINGCONFIGSENTRY']._serialized_end=670
  _globals['_IKVSTORECONFIG_INTCONFIGSENTRY']._serialized_start=672
  _globals['_IKVSTORECONFIG_INTCONFIGSENTRY']._serialized_end=721
  _globals['_IKVSTORECONFIG_FLOATCONFIGSENTRY']._serialized_start=723
  _globals['_IKVSTORECONFIG_FLOATCONFIGSENTRY']._serialized_end=774
  _globals['_IKVSTORECONFIG_BYTESCONFIGSENTRY']._serialized_start=776
  _globals['_IKVSTORECONFIG_BYTESCONFIGSENTRY']._serialized_end=827
  _globals['_IKVSTORECONFIG_BOOLEANCONFIGSENTRY']._serialized_start=829
  _globals['_IKVSTORECONFIG_BOOLEANCONFIGSENTRY']._serialized_end=882
# @@protoc_insertion_point(module_scope)
