# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eservices.proto\x12\nikvschemas\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0c\x63ommon.proto\"!\n\x11HelloWorldRequest\x12\x0c\n\x04\x65\x63ho\x18\x01 \x01(\t\"\"\n\x12HelloWorldResponse\x12\x0c\n\x04\x65\x63ho\x18\x01 \x01(\t\"#\n\x13HealthCheckResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\"\xc8\x01\n\x18UpsertFieldValuesRequest\x12L\n\x1buserStoreContextInitializer\x18\x01 \x01(\x0b\x32\'.ikvschemas.UserStoreContextInitializer\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x08\x64ocument\x18\x03 \x01(\x0b\x32\x1d.ikvschemas.IKVDocumentOnWire\"\xce\x01\n\x1d\x42\x61tchUpsertFieldValuesRequest\x12L\n\x1buserStoreContextInitializer\x18\x01 \x01(\x0b\x32\'.ikvschemas.UserStoreContextInitializer\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\tdocuments\x18\x03 \x03(\x0b\x32\x1d.ikvschemas.IKVDocumentOnWire\"\xdd\x01\n\x17\x44\x65leteFieldValueRequest\x12L\n\x1buserStoreContextInitializer\x18\x01 \x01(\x0b\x32\'.ikvschemas.UserStoreContextInitializer\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\ndocumentId\x18\x03 \x01(\x0b\x32\x1d.ikvschemas.IKVDocumentOnWire\x12\x12\n\nfieldNames\x18\x04 \x03(\t\"\xe4\x01\n\x1d\x42\x61tchDeleteFieldValuesRequest\x12L\n\x1buserStoreContextInitializer\x18\x01 \x01(\x0b\x32\'.ikvschemas.UserStoreContextInitializer\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0b\x64ocumentIds\x18\x03 \x03(\x0b\x32\x1d.ikvschemas.IKVDocumentOnWire\x12\x12\n\nfieldNames\x18\x04 \x03(\t\"\xc7\x01\n\x15\x44\x65leteDocumentRequest\x12L\n\x1buserStoreContextInitializer\x18\x01 \x01(\x0b\x32\'.ikvschemas.UserStoreContextInitializer\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\ndocumentId\x18\x03 \x01(\x0b\x32\x1d.ikvschemas.IKVDocumentOnWire\"\xce\x01\n\x1b\x42\x61tchDeleteDocumentsRequest\x12L\n\x1buserStoreContextInitializer\x18\x01 \x01(\x0b\x32\'.ikvschemas.UserStoreContextInitializer\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0b\x64ocumentIds\x18\x03 \x03(\x0b\x32\x1d.ikvschemas.IKVDocumentOnWire\"\xd4\x01\n\x11\x44ropFieldsRequest\x12L\n\x1buserStoreContextInitializer\x18\x01 \x01(\x0b\x32\'.ikvschemas.UserStoreContextInitializer\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x66ield_names\x18\x03 \x03(\t\x12\x1b\n\x13\x66ield_name_prefixes\x18\x04 \x03(\t\x12\x10\n\x08\x64rop_all\x18\x05 \x01(\x08\"Q\n\x0b\x46ieldSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x05\x12(\n\tfieldType\x18\x03 \x01(\x0e\x32\x15.ikvschemas.FieldType\"i\n\x19GetUserStoreConfigRequest\x12L\n\x1buserStoreContextInitializer\x18\x01 \x01(\x0b\x32\'.ikvschemas.UserStoreContextInitializer\"N\n\x1aGetUserStoreConfigResponse\x12\x30\n\x0cglobalConfig\x18\x01 \x01(\x0b\x32\x1a.ikvschemas.IKVStoreConfig\"\x08\n\x06Status\"e\n\x1bUserStoreContextInitializer\x12\x33\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32\x1e.ikvschemas.AccountCredentials\x12\x11\n\tstoreName\x18\x02 \x01(\t\"?\n\x12\x41\x63\x63ountCredentials\x12\x11\n\taccountId\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x63\x63ountPasskey\x18\x02 \x01(\t2\x88\x06\n\x14InlineKVWriteService\x12M\n\nhelloWorld\x12\x1d.ikvschemas.HelloWorldRequest\x1a\x1e.ikvschemas.HelloWorldResponse\"\x00\x12O\n\x11upsertFieldValues\x12$.ikvschemas.UpsertFieldValuesRequest\x1a\x12.ikvschemas.Status\"\x00\x12Y\n\x16\x62\x61tchUpsertFieldValues\x12).ikvschemas.BatchUpsertFieldValuesRequest\x1a\x12.ikvschemas.Status\"\x00\x12N\n\x11\x64\x65leteFieldValues\x12#.ikvschemas.DeleteFieldValueRequest\x1a\x12.ikvschemas.Status\"\x00\x12Y\n\x16\x62\x61tchDeleteFieldValues\x12).ikvschemas.BatchDeleteFieldValuesRequest\x1a\x12.ikvschemas.Status\"\x00\x12I\n\x0e\x64\x65leteDocument\x12!.ikvschemas.DeleteDocumentRequest\x1a\x12.ikvschemas.Status\"\x00\x12U\n\x14\x62\x61tchDeleteDocuments\x12\'.ikvschemas.BatchDeleteDocumentsRequest\x1a\x12.ikvschemas.Status\"\x00\x12\x41\n\ndropFields\x12\x1d.ikvschemas.DropFieldsRequest\x1a\x12.ikvschemas.Status\"\x00\x12\x65\n\x12getUserStoreConfig\x12%.ikvschemas.GetUserStoreConfigRequest\x1a&.ikvschemas.GetUserStoreConfigResponse\"\x00\x32X\n\x0c\x41\x64minService\x12H\n\x0bhealthCheck\x12\x16.google.protobuf.Empty\x1a\x1f.ikvschemas.HealthCheckResponse\"\x00\x42 \n\x14\x63om.inlineio.schemasZ\x08schemas/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.inlineio.schemasZ\010schemas/'
  _globals['_HELLOWORLDREQUEST']._serialized_start=106
  _globals['_HELLOWORLDREQUEST']._serialized_end=139
  _globals['_HELLOWORLDRESPONSE']._serialized_start=141
  _globals['_HELLOWORLDRESPONSE']._serialized_end=175
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=177
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=212
  _globals['_UPSERTFIELDVALUESREQUEST']._serialized_start=215
  _globals['_UPSERTFIELDVALUESREQUEST']._serialized_end=415
  _globals['_BATCHUPSERTFIELDVALUESREQUEST']._serialized_start=418
  _globals['_BATCHUPSERTFIELDVALUESREQUEST']._serialized_end=624
  _globals['_DELETEFIELDVALUEREQUEST']._serialized_start=627
  _globals['_DELETEFIELDVALUEREQUEST']._serialized_end=848
  _globals['_BATCHDELETEFIELDVALUESREQUEST']._serialized_start=851
  _globals['_BATCHDELETEFIELDVALUESREQUEST']._serialized_end=1079
  _globals['_DELETEDOCUMENTREQUEST']._serialized_start=1082
  _globals['_DELETEDOCUMENTREQUEST']._serialized_end=1281
  _globals['_BATCHDELETEDOCUMENTSREQUEST']._serialized_start=1284
  _globals['_BATCHDELETEDOCUMENTSREQUEST']._serialized_end=1490
  _globals['_DROPFIELDSREQUEST']._serialized_start=1493
  _globals['_DROPFIELDSREQUEST']._serialized_end=1705
  _globals['_FIELDSCHEMA']._serialized_start=1707
  _globals['_FIELDSCHEMA']._serialized_end=1788
  _globals['_GETUSERSTORECONFIGREQUEST']._serialized_start=1790
  _globals['_GETUSERSTORECONFIGREQUEST']._serialized_end=1895
  _globals['_GETUSERSTORECONFIGRESPONSE']._serialized_start=1897
  _globals['_GETUSERSTORECONFIGRESPONSE']._serialized_end=1975
  _globals['_STATUS']._serialized_start=1977
  _globals['_STATUS']._serialized_end=1985
  _globals['_USERSTORECONTEXTINITIALIZER']._serialized_start=1987
  _globals['_USERSTORECONTEXTINITIALIZER']._serialized_end=2088
  _globals['_ACCOUNTCREDENTIALS']._serialized_start=2090
  _globals['_ACCOUNTCREDENTIALS']._serialized_end=2153
  _globals['_INLINEKVWRITESERVICE']._serialized_start=2156
  _globals['_INLINEKVWRITESERVICE']._serialized_end=2932
  _globals['_ADMINSERVICE']._serialized_start=2934
  _globals['_ADMINSERVICE']._serialized_end=3022
# @@protoc_insertion_point(module_scope)
